@@ -1,4 +1,4 @@
-# $Id: Node.pm,v 1.27 2004/04/11 23:36:19 joern Exp $
+# $Id: Node.pm,v 1.30 2005/06/19 13:37:56 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -193,9 +193,16 @@ sub get_popen_code {
 	my $self = shift;
 	my %par = @_;
 	my ($command) = @par{'command'};
+
+	$command = "umask 0002; $command";
 	
 	return $command if $self->is_master;
 
+	#-- Set LD_ASSUME_KERNEL on the nodes as well,
+	#-- if set on the master.
+	$command = "export LD_ASSUME_KERNEL=$ENV{LD_ASSUME_KERNEL}; $command"
+		if $ENV{LD_ASSUME_KERNEL};
+
 	my $username = $self->username;
 	my $name     = $self->hostname;
 	my $ssh_cmd  = $self->ssh_cmd  || 'ssh -x';
@@ -305,7 +312,6 @@ sub run_tests {
 			$output .= $_[0]."\n";
 		},
 		cb_finished => sub {
-			$self->parse_test_output;
 			$self->set_test_result (
 				$self->parse_test_output (
 					output => $output
