@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.44 2005/05/16 10:45:48 joern Exp $
+# $Id: Title.pm,v 1.45.2.1 2005/08/14 21:22:29 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -277,10 +277,10 @@ sub get_merge_audio_command {
 	} else {
 		$command .=
 			"dr_exec avimerge".
-			" -i $avi_file".
 			" -p $audio_file".
 			" -a $target_nr".
-			" -o $avi_file.merged &&".
+			" -o $avi_file.merged".
+			" -i $avi_file &&".
 			" mv $avi_file.merged $target_file &&".
 			" rm $audio_file &&".
 			" echo DVDRIP_SUCCESS";
@@ -348,7 +348,7 @@ sub get_merge_psu_command {
 		"${nice}dr_exec ";
 
 	if ( $self->is_ogg ) {
-		$command .="ogmcat -v -v";	# -v -v to prevent timeouts
+		$command .="ogmcat -v -v ";	# -v -v to prevent timeouts
 	} else {
 		$command .="avimerge ";
 	}
