@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.49 2005/06/19 13:38:24 joern Exp $
+# $Id: Config.pm,v 1.49.2.2 2006/03/18 11:26:51 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -306,7 +306,7 @@ my %CONFIG_PARAMETER = (
 	workaround_nptl_bugs => {
 		label	=> __"Workaround transcode NPTL bugs",
 		type	=> 'switch',
-		value	=> 1,
+		value	=> 0,
 	},
 	nptl_ld_assume_kernel => {
 		label   => __"Set LD_ASSUME_KERNEL to",
@@ -692,7 +692,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.49 2005/06/19 13:38:24 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.49.2.2 2006/03/18 11:26:51 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -791,8 +791,8 @@ sub test_play_dvd_command   	{ _executable (@_) 	}
 sub test_play_file_command  	{ _executable (@_) 	}
 sub test_play_stdin_command 	{ _executable (@_) 	}
 sub test_rar_command 		{ _executable (@_) 	}
-sub test_dvd_device		{ _writable (@_)	}
-sub test_writer_device		{ _writable (@_)	}
+sub test_dvd_device		{ _exists (@_)		}
+sub test_writer_device		{ _exists (@_)		}
 sub test_dvd_mount_point	{ _exists (@_)		}
 sub test_base_project_dir	{ _writable (@_)	}
 sub test_dvdrip_files_dir	{ _writable (@_)	}
