@@ -1,4 +1,4 @@
-# $Id: TranscodeTab.pm,v 1.83.2.14 2003/10/26 12:45:13 joern Exp $
+# $Id: TranscodeTab.pm,v 1.92 2005/06/19 13:42:52 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Project;
+use Locale::TextDomain qw (video.dvdrip);
 
 use Video::DVDRip::GUI::MinSizeGroup;
 use Video::DVDRip::GUI::Project::TranscodeTabAudio;
@@ -100,11 +101,14 @@ sub create_transcode_tab {
 	
 	# text entry signals
 	foreach my $attr (qw ( tc_video_codec tc_options tc_nice
-			       tc_video_af6_codec tc_video_bitrate
-			       tc_video_framerate tc_execute_afterwards
+			       tc_video_af6_codec tc_video_bitrate tc_video_bpp
+			       tc_video_framerate tc_keyframe_interval
+			        tc_execute_afterwards
 			       tc_start_frame tc_end_frame
 			       tc_target_size )) {
-		$widgets->{$attr}->signal_connect ("changed", sub {
+		my $widget = $widgets->{$attr};
+		$widget = $widget->entry if $attr eq 'tc_video_bpp';
+		$widget->signal_connect ("changed", sub {
 			my ($widget, $method) = @_;
 			return 1 if not $self->selected_title;
 			return 1 if $self->in_transcode_init;
@@ -115,9 +119,14 @@ sub create_transcode_tab {
 			$title->$method ( $value );
 			if ( $method eq "set_tc_target_size" ) {
 				$self->calc_video_bitrate;
-			}
-			$self->update_storage_labels
-				if $method eq 'set_tc_video_bitrate';
+			} elsif ( $method eq 'set_tc_video_bitrate' ) {
+				$title->set_tc_video_bitrate_last_edit('bitrate');
+				$self->update_storage_labels;
+			} elsif ( $method eq 'set_tc_video_bpp' ) {
+				$title->set_tc_video_bitrate_last_edit('bpp');
+				$self->update_storage_labels;
+			}			
+
 			if ( $attr eq 'tc_video_codec' ) {
 				if ( $value eq 'VCD' or $value eq 'XVCD') {
 					$self->burn_widgets
@@ -148,9 +157,9 @@ sub create_transcode_tab {
 				     $value > 2048 and not $big_target_size_warned_today ) {
 					$self->message_window (
 						message =>
-							"Warning: AVI files shouldn't get bigger than 2 GB.\n".
-							"Some players can't play them and you can't seek\n".
-							"within the files. Better use OGG for such big files."
+							__"Warning: AVI files shouldn't get bigger than 2 GB.\n".
+                                                         "Some players can't play them and you can't seek\n".
+                                                         "within the files. Better use OGG for such big files."
 					);
 					$big_target_size_warned_today = 1;
 				}
@@ -221,7 +230,7 @@ sub create_container_options {
 	my ($popup_menu, $popup, $item, %popup_entries);
 
 	# Frame
-	$frame = Gtk::Frame->new ("Container options");
+	$frame = Gtk::Frame->new (__"Container options");
 	$frame->show;
 
 	# Frame HBox
@@ -241,7 +250,7 @@ sub create_container_options {
 	$row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Select container");
+	$label = Gtk::Label->new (__"Select container");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$hsize_group->add ($hbox);
@@ -299,7 +308,7 @@ sub create_video_options {
 	my ($popup_menu, $popup, $item, %popup_entries, $button);
 
 	# Frame
-	$frame = Gtk::Frame->new ("Video options");
+	$frame = Gtk::Frame->new (__"Video options");
 	$frame->show;
 
 	# Frame HBox
@@ -319,7 +328,7 @@ sub create_video_options {
 	$row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Video codec");
+	$label = Gtk::Label->new (__"Video codec");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -333,7 +342,7 @@ sub create_video_options {
 	$entry->set_usize(80,undef);
 	$hbox->pack_start($entry, 0, 1, 0);
 
-	$button = Gtk::Button->new (" Configure... ");
+	$button = Gtk::Button->new (__"Configure...");
 	$button->show;
 	$hbox->pack_start ($button, 0, 1, 0);
 
@@ -359,8 +368,9 @@ sub create_video_options {
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
 	$hsize_group->add ($hbox);
 
-	$hbox = Gtk::HBox->new;
+	$hbox = Gtk::HBox->new (0, 20);
 	$hbox->show;
+
 	$entry = Gtk::Entry->new;
 	$entry->show;
 	$entry->set_usize(80,undef);
@@ -369,11 +379,32 @@ sub create_video_options {
 
 	$self->transcode_widgets->{tc_video_af6_codec} = $entry;
 
+	# Keyframe interval
+	my $hbox2 = Gtk::HBox->new;
+	$hbox2->show;
+	$hbox->pack_start($hbox2, 0, 1, 0);
+
+	$label = Gtk::Label->new (__"Keyframe interval");
+	$label->show;
+	$hbox2->pack_start($label, 0, 1, 0);
+
+	$entry = Video::DVDRip::CheckedCombo->new(
+		is_number => 1,
+		may_empty => 0,
+		may_fractional => 0,
+	);
+	$entry->show;
+	$entry->set_popdown_strings (25, 50, 100, 150, 250);
+	$entry->set_usize(60,undef);
+	$hbox2->pack_start($entry, 0, 1, 0);
+
+	$self->transcode_widgets->{tc_keyframe_interval} = $entry->entry;
+
 	# Video Framerate
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Video framerate");
+	$label = Gtk::Label->new (__"Video framerate");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -403,7 +434,7 @@ sub create_video_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("2-pass encoding");
+	$label = Gtk::Label->new (__"2-pass encoding");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -411,13 +442,13 @@ sub create_video_options {
 
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	my $radio_yes = Gtk::RadioButton->new ("Yes");
+	my $radio_yes = Gtk::RadioButton->new (__"Yes");
 	$radio_yes->show;
 	$hbox->pack_start($radio_yes, 0, 1, 0);
-	my $radio_no = Gtk::RadioButton->new ("No", $radio_yes);
+	my $radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
 	$radio_no->show;
 	$hbox->pack_start($radio_no, 0, 1, 0);
-	my $check_multipass_reuse_log = Gtk::CheckButton->new ("Reuse log");
+	my $check_multipass_reuse_log = Gtk::CheckButton->new (__"Reuse log");
 	$check_multipass_reuse_log->show;
 	$hbox->pack_start($check_multipass_reuse_log, 0, 1, 0);
 
@@ -431,7 +462,7 @@ sub create_video_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Deinterlace mode");
+	$label = Gtk::Label->new (__"Deinterlace mode");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -471,13 +502,13 @@ sub create_video_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Filters");
+	$label = Gtk::Label->new (__"Filters");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
 	$hsize_group->add ($hbox);
 
-	$button = Gtk::Button->new ("  Configure filters & preview...  ");
+	$button = Gtk::Button->new (__"Configure filters & preview...");
 	$button->show;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
@@ -488,7 +519,7 @@ sub create_video_options {
 
 	if ( $self->version ("transcode") < 603 ) {
 		$button->set_sensitive(0);
-		$button->child->set (" Needs transcode 0.6.3 ");
+		$button->child->set (__"Needs transcode 0.6.3");
 	}
 
 	return $frame;
@@ -503,7 +534,7 @@ sub create_video_bitrate_calc {
 	my ($popup_menu, $popup, $item, %popup_entries);
 
 	# Frame
-	$frame = Gtk::Frame->new ("Video bitrate calculation");
+	$frame = Gtk::Frame->new (__"Video bitrate calculation");
 	$frame->show;
 
 	# Frame HBox
@@ -523,7 +554,7 @@ sub create_video_bitrate_calc {
 	$row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Target media");
+	$label = Gtk::Label->new (__"Target media");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -540,10 +571,10 @@ sub create_video_bitrate_calc {
 	$popup->set_menu($popup_menu);
 
 	%popup_entries = (
-		1 => "one",
-		2 => "two",
-		3 => "three",
-		4 => "four",
+		1 => __"one",
+		2 => __"two",
+		3 => __"three",
+		4 => __"four",
 	);
 
 	foreach my $key ( sort keys %popup_entries ) {
@@ -610,7 +641,7 @@ sub create_video_bitrate_calc {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Target size");
+	$label = Gtk::Label->new (__"Target size");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -639,7 +670,7 @@ sub create_video_bitrate_calc {
 	
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	my $checkbox = Gtk::CheckButton->new ("Use range");
+	my $checkbox = Gtk::CheckButton->new (__"Use range");
 	$checkbox->show;
 	$hbox->pack_start ($checkbox, 0, 1, 0);
 	$checkbox->signal_connect (
@@ -661,7 +692,7 @@ sub create_video_bitrate_calc {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Video bitrate");
+	$label = Gtk::Label->new (__"Video bitrate");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -682,14 +713,32 @@ sub create_video_bitrate_calc {
 	$label->show;
 	$hbox->pack_start ($label, 0, 1, 0);
 	
+	$self->transcode_widgets->{tc_video_bitrate} = $entry;
+
+	# bpp
+	$entry = Video::DVDRip::CheckedCombo->new (
+		is_number      => 1,
+		may_fractional => 1,
+		may_empty      => 0,
+	);
+	$entry->show;
+	my @bpp;
+	for ( my $b = 1.0; $b > 0 && push @bpp, sprintf("%.2f",$b); $b -= 0.05 ) {};
+	$entry->set_popdown_strings (@bpp);
+	$entry->set_usize(60,undef);
+	$hbox->pack_start($entry, 0, 1, 0);
+
+	$label = Gtk::Label->new ("bpp");
+	$label->show;
+	$hbox->pack_start ($label, 0, 1, 0);
+
+	$self->transcode_widgets->{tc_video_bpp} = $entry;
 
 	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
 
-	$self->transcode_widgets->{tc_video_bitrate} = $entry;
-
 	$hbox = Gtk::HBox->new;
 	$hbox->show;	
-	my $checkbox = Gtk::CheckButton->new ("Manual");
+	my $checkbox = Gtk::CheckButton->new (__"Manual");
 	$checkbox->show;
 	$hbox->pack_start ($checkbox, 0, 1, 0);
 	$checkbox->signal_connect (
@@ -699,6 +748,7 @@ sub create_video_bitrate_calc {
 			return 1 if $self->in_transcode_init;
 			$title->set_tc_video_bitrate_manual($_[0]->active);
 			if ( not $title->tc_video_bitrate_manual ) {
+				$title->set_tc_video_bitrate_last_edit("bitrate");
 				$self->calc_video_bitrate;
 			}
 			$self->init_transcode_values;
@@ -723,7 +773,7 @@ sub create_transcode_operate {
 	my ($button, $button_box);
 
 	# Frame
-	$frame = Gtk::Frame->new ("Operate");
+	$frame = Gtk::Frame->new (__"Operate");
 	$frame->show;
 
 	# Frame HBox
@@ -739,19 +789,19 @@ sub create_transcode_operate {
 	$frame_hbox->pack_start ($button_box, 1, 0, 1);
 
 	# Transcode and split Button
-	$button = Gtk::Button->new_with_label ("Transcode + Split");
+	$button = Gtk::Button->new_with_label (__"Transcode + Split");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->transcode ( split => 1 ) } );
 	$button_box->add ($button);
 
 	# Transcode only Button
-	$button = Gtk::Button->new_with_label ("Transcode");
+	$button = Gtk::Button->new_with_label (__"Transcode");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->transcode } );
 	$button_box->add ($button);
 
 	# Split only Button
-	$button = Gtk::Button->new_with_label ("Split AVI");
+	$button = Gtk::Button->new_with_label (__"Split AVI");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->avisplit } );
 	$button_box->add ($button);
@@ -759,7 +809,7 @@ sub create_transcode_operate {
 	$self->transcode_widgets->{avisplit_button} = $button;
 
 	# View AVI Button
-	$button = Gtk::Button->new_with_label ("View AVI");
+	$button = Gtk::Button->new_with_label (__"View AVI");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->view_avi } );
 	$button_box->add ($button);
@@ -767,7 +817,7 @@ sub create_transcode_operate {
 	$self->transcode_widgets->{view_avi_button} = $button;
 
 	# Add Project To Cluster Button
-	$button = Gtk::Button->new_with_label ("Add to cluster");
+	$button = Gtk::Button->new_with_label (__"Add to cluster");
 	$button->show;
 	$button->signal_connect ("clicked", sub { $self->add_to_cluster } );
 	$button_box->add ($button);
@@ -786,7 +836,7 @@ sub create_general_options {
 	my ($popup_menu, $popup, $item, %popup_entries);
 
 	# Frame
-	$frame = Gtk::Frame->new ("General options");
+	$frame = Gtk::Frame->new (__"General options");
 	$frame->show;
 
 	# Frame HBox
@@ -806,7 +856,7 @@ sub create_general_options {
 	$row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Frame range");
+	$label = Gtk::Label->new (__"Frame range");
 	$label->set_line_wrap(1);
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
@@ -859,7 +909,7 @@ sub create_general_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("transcode options");
+	$label = Gtk::Label->new (__"transcode options");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -878,7 +928,7 @@ sub create_general_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Process nice level");
+	$label = Gtk::Label->new (__"Process nice level");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -904,7 +954,7 @@ sub create_general_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Preview window");
+	$label = Gtk::Label->new (__"Preview window");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -912,10 +962,10 @@ sub create_general_options {
 
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	my $radio_yes = Gtk::RadioButton->new ("Yes");
+	my $radio_yes = Gtk::RadioButton->new (__"Yes");
 	$radio_yes->show;
 	$hbox->pack_start($radio_yes, 0, 1, 0);
-	my $radio_no = Gtk::RadioButton->new ("No", $radio_yes);
+	my $radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
 	$radio_no->show;
 	$hbox->pack_start($radio_no, 0, 1, 0);
 	
@@ -928,7 +978,7 @@ sub create_general_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Use PSU core");
+	$label = Gtk::Label->new (__"Use PSU core");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -936,10 +986,10 @@ sub create_general_options {
 
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$radio_yes = Gtk::RadioButton->new ("Yes");
+	$radio_yes = Gtk::RadioButton->new (__"Yes");
 	$radio_yes->show;
 	$hbox->pack_start($radio_yes, 0, 1, 0);
-	$radio_no = Gtk::RadioButton->new ("No", $radio_yes);
+	$radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
 	$radio_no->show;
 	$hbox->pack_start($radio_no, 0, 1, 0);
 	
@@ -953,7 +1003,7 @@ sub create_general_options {
 	++$row;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Execute afterwards");
+	$label = Gtk::Label->new (__"Execute afterwards");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
@@ -969,7 +1019,7 @@ sub create_general_options {
 
 	$self->transcode_widgets->{tc_execute_afterwards} = $entry;
 
-	my $checkbox = Gtk::CheckButton->new ("And exit");
+	my $checkbox = Gtk::CheckButton->new (__"And exit");
 	$checkbox->show;
 	$hbox->pack_start ($checkbox, 1, 1, 0);
 	$self->transcode_widgets->{tc_exit_afterwards} = $checkbox;
@@ -986,7 +1036,7 @@ sub create_calculated_storage {
 	my ($popup_menu, $popup, $item, %popup_entries, $button);
 
 	# Frame
-	$frame = Gtk::Frame->new ("Calculated storage");
+	$frame = Gtk::Frame->new (__"Calculated storage");
 	$frame->show;
 
 	# Frame HBox
@@ -996,7 +1046,7 @@ sub create_calculated_storage {
 	$frame->add ($frame_hbox);
 
 	# Table
-	$table = Gtk::Table->new ( 3, 4, 0 );
+	$table = Gtk::Table->new ( 3, 5, 0 );
 	$table->show;
 	$table->set_row_spacings ( $TABLE_SPACING );
 	$table->set_col_spacings ( $TABLE_SPACING + 5 );
@@ -1015,24 +1065,31 @@ sub create_calculated_storage {
 
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Non video");
+	$label = Gtk::Label->new (__"Audio");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 1, 2, $row, $row+1);
 
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
-	$label = Gtk::Label->new ("Total");
+	$label = Gtk::Label->new (__"Other");
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 2, 3, $row, $row+1);
 
+	$hbox = Gtk::HBox->new;
+	$hbox->show;
+	$label = Gtk::Label->new (__"Total");
+	$label->show;
+	$hbox->pack_start($label, 0, 1, 0);
+	$table->attach_defaults ($hbox, 3, 4, $row, $row+1);
+
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
 	$button = Gtk::Button->new (" Details... ");
 	$button->show;
 	$hbox->pack_start($button, 0, 1, 0);
-	$table->attach_defaults ($hbox, 3, 4, $row, $row+1);
+	$table->attach_defaults ($hbox, 4, 5, $row, $row+1);
 
 	$button->signal_connect ("clicked", sub { $self->show_calc_details } );
 
@@ -1040,7 +1097,7 @@ sub create_calculated_storage {
 	++$row;
 	my $sep = Gtk::HSeparator->new;
 	$sep->show;
-	$table->attach_defaults ($sep, 0, 3, $row, $row+1);
+	$table->attach_defaults ($sep, 0, 4, $row, $row+1);
 
 	# Values
 
@@ -1073,6 +1130,17 @@ sub create_calculated_storage {
 	$label->show;
 	$hbox->pack_start($label, 0, 1, 0);
 	$table->attach_defaults ($hbox, 2, 3, $row, $row+1);
+	$self->transcode_widgets->{label_size_other} = $label;
+	$label = Gtk::Label->new ("MB");
+	$label->show;
+	$hbox->pack_start($label, 0, 1, 0);
+
+	$hbox = Gtk::HBox->new;
+	$hbox->show;
+	$label = Gtk::Label->new ("");
+	$label->show;
+	$hbox->pack_start($label, 0, 1, 0);
+	$table->attach_defaults ($hbox, 3, 4, $row, $row+1);
 	$self->transcode_widgets->{label_size_total} = $label;
 	$label = Gtk::Label->new ("MB");
 	$label->show;
@@ -1097,11 +1165,14 @@ sub init_transcode_values {
 	foreach my $attr (qw ( tc_options tc_nice
 			       tc_video_af6_codec tc_video_bitrate
 			       tc_video_framerate tc_target_size
+			       tc_keyframe_interval
 			       tc_start_frame tc_end_frame
 			       tc_execute_afterwards )) {
 		$widgets->{$attr}->set_text ($self->selected_title->$attr());
 	}
 
+	$widgets->{tc_video_bpp}->entry->set_text($self->selected_title->tc_video_bpp);
+
 	my $chapter_mode    = $title->tc_use_chapter_mode;
 	my $multipass       = $title->tc_multipass;
 	my $deinterlace     = $title->tc_deinterlace;
@@ -1120,9 +1191,11 @@ sub init_transcode_values {
 	$widgets->{tc_multipass_reuse_log}->set_sensitive($multipass);
 	$widgets->{tc_multipass_reuse_log}->set_active($title->tc_multipass_reuse_log);
 
+	#-- determine index for deinterlace popup (fishy)
 	$deinterlace = 4 if $deinterlace eq '32detect';
-	$deinterlace = 5 if $deinterlace eq 'ivtc';
-	$deinterlace = 6 if $deinterlace eq 'smart';
+	$deinterlace = 5 if $deinterlace eq '5';
+	$deinterlace = 6 if $deinterlace eq 'ivtc';
+	$deinterlace = 7 if $deinterlace eq 'smart';
 
 	$widgets->{tc_deinterlace_popup}->set_history ($deinterlace);
 #	$widgets->{tc_anti_alias_popup}->set_history ($anti_alias);
@@ -1162,13 +1235,19 @@ sub init_transcode_values {
 
 	my $manual_sensitive;
 	my $bitrate_sensitive;
-
-	$manual_sensitive  = $title->tc_video_codec !~ /^S?VCD$/;
-	$bitrate_sensitive = $title->tc_video_bitrate_manual;
-	$bitrate_sensitive = 0 if $title->tc_video_codec eq 'VCD';
+	my $target_size_sensitive;
+	
+	$manual_sensitive      = $title->tc_video_codec !~ /^S?VCD$/;
+	$bitrate_sensitive     = $title->tc_video_bitrate_manual;
+	$bitrate_sensitive     = 0 if $title->tc_video_codec eq 'VCD';
+	$target_size_sensitive = !$title->tc_video_bitrate_manual;
 	
 	$widgets->{tc_video_bitrate_manual}->set_sensitive($manual_sensitive);
 	$widgets->{tc_video_bitrate}->set_sensitive($bitrate_sensitive);
+	$widgets->{tc_video_bpp}->set_sensitive($bitrate_sensitive);
+	
+	$widgets->{$_}->set_sensitive($target_size_sensitive)
+		for qw(tc_disc_cnt_popup tc_target_size);
 	
 	$self->set_in_transcode_init(1);
 	if ( not $manual_sensitive ) {
@@ -1214,8 +1293,8 @@ sub switch_to_mpeg_encoding {
 
 	$widgets->{avisplit_button}->set_sensitive(0);
 	$widgets->{cluster_button}->set_sensitive(0);
-	$widgets->{view_avi_button}->child->set("View MPEG");
-	$widgets->{tc_video_codec_label}->set ("MPEG Variant");
+	$widgets->{view_avi_button}->child->set(__"View MPEG");
+	$widgets->{tc_video_codec_label}->set (__"MPEG Variant");
 
 	$_->hide foreach @{$widgets->{tc_mpeg_hide}};
 
@@ -1236,16 +1315,16 @@ sub switch_to_divx_encoding {
 
 	$widgets->{avisplit_button}->set_sensitive(1);
 	$widgets->{cluster_button}->set_sensitive(1);
-	$widgets->{tc_video_codec_label}->set ("Video codec");
+	$widgets->{tc_video_codec_label}->set (__"Video codec");
 	$widgets->{tc_multipass_reuse_log}->set_sensitive(0)
 		if not $title->tc_multipass;
 
 	if ( $title->is_ogg ) {
-		$widgets->{view_avi_button}->child->set("View OGG");
-		$widgets->{avisplit_button}->child->set("Split OGG");
+		$widgets->{view_avi_button}->child->set(__"View OGG");
+		$widgets->{avisplit_button}->child->set(__"Split OGG");
 	} else {
-		$widgets->{view_avi_button}->child->set("View AVI");
-		$widgets->{avisplit_button}->child->set("Split AVI");
+		$widgets->{view_avi_button}->child->set(__"View AVI");
+		$widgets->{avisplit_button}->child->set(__"Split AVI");
 	}
 
 	1;
@@ -1295,7 +1374,9 @@ sub calc_video_bitrate {
 	return 1 if not $title;
 	
 	$title->calc_video_bitrate;
+
 	$self->transcode_widgets->{tc_video_bitrate}->set_text($title->tc_video_bitrate);
+	$self->transcode_widgets->{tc_video_bpp}->entry->set_text($title->tc_video_bpp);
 	
 	1;
 }
@@ -1306,22 +1387,34 @@ sub update_storage_labels {
 	my $title = $self->selected_title;
 	return 1 if not $title;
 
-	my $bc = Video::DVDRip::BitrateCalc->new (
-		title => $title,
-	);
-	$bc->calculate_video_bitrate;
+	my $bc = Video::DVDRip::BitrateCalc->new ( title => $title );
+	$bc->calculate;
 
 	my $video_label = $self->transcode_widgets->{label_size_video};
 	my $audio_label = $self->transcode_widgets->{label_size_audio};
+	my $other_label = $self->transcode_widgets->{label_size_other};
 	my $total_label = $self->transcode_widgets->{label_size_total};
 
 	$video_label->set_text(sprintf("%.2f",$bc->video_size));
-	$audio_label->set_text(sprintf("%.2f",$bc->non_video_size));
-	$total_label->set_text(sprintf("%.2f",$bc->video_size + $bc->non_video_size));
+	$audio_label->set_text(sprintf("%.2f",$bc->audio_size ));
+	$other_label->set_text(sprintf("%.2f",$bc->other_size + $bc->cont_overhead_size ));
+	$total_label->set_text(sprintf("%.2f",$bc->file_size));
 
 	my $bc_window = eval { $self->comp('bitrate_calc') };
 	$bc_window->init_calc_list if $bc_window;
 
+	if ( $title->tc_video_bitrate_manual ) {
+		$self->set_in_transcode_init(1);
+		if ( $title->tc_video_bitrate_last_edit eq 'bpp' ) {
+			$title->set_tc_video_bitrate($bc->video_bitrate);
+			$self->transcode_widgets->{tc_video_bitrate}->set_text($title->tc_video_bitrate);
+		} else {
+			$title->set_tc_video_bpp($bc->video_bpp);
+			$self->transcode_widgets->{tc_video_bpp}->entry->set_text($title->tc_video_bpp);
+		}
+		$self->set_in_transcode_init(0);
+	}
+
 	1;
 }
 
@@ -1351,7 +1444,7 @@ sub transcode {
 
 	if ( not $title->is_ripped ) {
 		$self->message_window (
-			message => "You first have to rip this title."
+			message => __"You first have to rip this title."
 		);
 		return 1;
 	}
@@ -1359,7 +1452,7 @@ sub transcode {
 	if ( $title->tc_psu_core and
 	    ($title->tc_start_frame or $title->tc_end_frame) ) {
 		$self->message_window (
-			message => "You can't select a frame range with psu core."
+			message => __"You can't select a frame range with psu core."
 		);
 		return 1;
 	}
@@ -1367,29 +1460,29 @@ sub transcode {
 	if ( $title->tc_psu_core and
 	     $title->project->rip_mode ne 'rip' ) {
 		$self->message_window (
-			message => "PSU core only available for ripped DVD's."
+			message => __"PSU core only available for ripped DVD's."
 		);
 		return 1;
 	}
 
 	if ( $title->tc_use_chapter_mode and not @{$chapters} ) {
 		$self->message_window (
-			message => "No chapters selected."
+			message => __"No chapters selected."
 		);
 		return 1;
 	}
 
 	if ( $title->tc_use_chapter_mode and $split ) {
 		$self->message_window (
-			message => "Splitting AVI files in\n".
-				   "chapter mode makes no sense."
+			message => __"Splitting AVI files in\n".
+                                    "chapter mode makes no sense."
 		);
 		return 1;
 	}
 
 	if ( $title->get_first_audio_track == -1 ) {
 		$self->message_window (
-			message => "WARNING: no target audio track #0"
+			message => __"WARNING: no target audio track #0"
 		);
 	}
 
@@ -1397,8 +1490,8 @@ sub transcode {
 		if ( $title->tc_video_codec =~ /^X?VCD$/ ) {
 			$self->message_window (
 				message =>
-					"Having more than one audio track ".
-					"isn't possible on a (X)VCD."
+					__"Having more than one audio track ".
+                                         "isn't possible on a (X)VCD."
 			);
 			return 1;
 		}
@@ -1406,9 +1499,9 @@ sub transcode {
 		     keys %{$title->get_additional_audio_tracks} > 1 ) {
 			$self->message_window (
 				message =>
-					"WARNING: Having more than two audio tracks\n".
-					"on a (X)SVCD/CVD is not standard conform. You may\n".
-					"encounter problems on hardware players."
+					__"WARNING: Having more than two audio tracks\n".
+                                         "on a (X)SVCD/CVD is not standard conform. You may\n".
+                                         "encounter problems on hardware players."
 			);
 		}
 	}
@@ -1417,9 +1510,9 @@ sub transcode {
 	if ( $svcd_warning = $title->check_svcd_geometry ) {
 		$self->message_window (
 			message =>
-				"WARNING: $svcd_warning\n".
-				"You better cancel now and select the appropriate\n".
-				"preset on the Clip & Zoom page.",
+			       __x("WARNING {warning}\n", warning => $svcd_warning).
+                               __"You better cancel now and select the appropriate\n".
+                                 "preset on the Clip & Zoom page.",
 		);
 	}
 
@@ -1428,7 +1521,8 @@ sub transcode {
 		subtitle_test => $subtitle_test
 	) if not $subtitle_test
 	     and $title->has_vbr_audio
-	     and $title->tc_multipass;
+	     and $title->tc_multipass
+	     and not $title->multipass_log_is_reused;
 
 	my $nr;
 	my $job;
@@ -1445,11 +1539,10 @@ sub transcode {
 		$job->set_split ($split);
 
 		if ( not $subtitle_test and $title->tc_multipass ) {
-			if ( $title->tc_multipass_reuse_log and
-			     -f $title->multipass_log_dir."/divx4.log" ) {
+			if ( $title->multipass_log_is_reused ) {
 				$self->log (
-					"Skipping 1st pass as requested by ".
-					"reusing existent multipass logfile."
+					__"Skipping 1st pass as requested by ".
+                                         "reusing existent multipass logfile."
 				);
 			} else {
 				$job->set_pass (1);
@@ -1534,27 +1627,23 @@ sub transcode {
 	}
 
 	if ( $split ) {
-		$last_job->set_cb_finished ( sub {
-			$self->create_splitted_vobsub (
-				exec     => $exec,
-				last_job => $last_job
-			);
-			1;
-		} );
+		$self->create_splitted_vobsub (
+			exec     => $exec,
+			last_job => $last_job
+		);
 	} else {
-		$last_job->set_cb_finished ( sub {
-			$self->create_non_splitted_vobsub (
-				exec     => $exec,
-				last_job => $last_job
-			);
-			1;
-		} );
+		$self->create_non_splitted_vobsub (
+			exec     => $exec,
+			last_job => $last_job
+		);
 	}
 
 	$exec->set_cb_finished (sub {
 		return 1 if $exec->cancelled or $exec->errors_occured;
 		return 1 if $subtitle_test;
 		if ( $title->tc_execute_afterwards =~ /\S/ ) {
+			$self->log(__x("Execute command after transcoding: {command}",
+				   command => $title->tc_execute_afterwards));
 			system ("(".$title->tc_execute_afterwards.") &");
 		}
 		if ( $title->tc_exit_afterwards ) {
@@ -1577,8 +1666,8 @@ sub transcode_multipass_with_vbr_audio {
 	my %par = @_;
 	my ($split) = @par{'split'};
 
-	$self->log ("This title is transcoded with vbr audio ".
-		    "and video bitrate optimization.");
+	$self->log (__"This title is transcoded with vbr audio ".
+                     "and video bitrate optimization.");
 
 	my $title    = $self->selected_title;
 	my $chapters = $title->get_chapters;
@@ -1587,9 +1676,7 @@ sub transcode_multipass_with_vbr_audio {
 		$chapters = [ undef ];
 	}
 
-	my $bc = Video::DVDRip::BitrateCalc->new (
-		title => $title,
-	);
+	my $bc = Video::DVDRip::BitrateCalc->new ( title => $title );
 
 	my $nr;
 	my $job;
@@ -1631,10 +1718,11 @@ sub transcode_multipass_with_vbr_audio {
 	
 	# 3. after 1st pass: calculate video bitrate (real audio size known)
 	$last_job->set_cb_finished (sub {
-		$title->set_tc_video_bitrate ( $bc->calculate_video_bitrate );
-		$self->log ("Adjusted video bitrate to ".
-			    $title->tc_video_bitrate.
-			    " after vbr audio transcoding");
+		$bc->calculate;
+		$title->set_tc_video_bitrate ( $bc->video_bitrate );
+		$self->log (__x("Adjusted video bitrate to {video_bitrate} ".
+			       "after vbr audio transcoding",
+			       video_bitrate => $bc->video_bitrate) );
 		$self->init_transcode_values;
 		1;
 	});
@@ -1688,27 +1776,23 @@ sub transcode_multipass_with_vbr_audio {
 		$job->set_depends_on_jobs ( [ $last_job ] );
 		$last_job = $exec->add_job ( job => $job );
 
-		$last_job->set_cb_finished ( sub {
-			$self->create_splitted_vobsub (
-				exec     => $exec,
-				last_job => $last_job
-			);
-			1;
-		} );
+		$self->create_splitted_vobsub (
+			exec     => $exec,
+			last_job => $last_job
+		);
 	} else {
-		$last_job->set_cb_finished ( sub {
-			$self->create_non_splitted_vobsub (
-				exec     => $exec,
-				last_job => $last_job
-			);
-			1;
-		} );
+		$self->create_non_splitted_vobsub (
+			exec     => $exec,
+			last_job => $last_job
+		);
 	}
 
 	# 6. execute afterwards stuff
 	$exec->set_cb_finished (sub {
 		return 1 if $exec->cancelled or $exec->errors_occured;
 		if ( $title->tc_execute_afterwards =~ /\S/ ) {
+			$self->log(__x("Execute command after transcoding: {command}",
+				   command => $title->tc_execute_afterwards));
 			system ("(".$title->tc_execute_afterwards.") &");
 		}
 		if ( $title->tc_exit_afterwards ) {
@@ -1735,15 +1819,15 @@ sub avisplit {
 	
 	if ( $title->tc_use_chapter_mode ) {
 		$self->message_window (
-			message => "Splitting an AVI file in\n".
-				   "Chapter Mode makes no sense."
+			message => __"Splitting an AVI file in\n".
+                                    "Chapter Mode makes no sense."
 		);
 		return 1;
 	}
 
 	if ( not -f $title->avi_file ) {
 		$self->message_window (
-			message => "You first have to transcode this title."
+			message => __"You first have to transcode this title."
 		);
 		return 1;
 	}
@@ -1758,13 +1842,10 @@ sub avisplit {
 
 	$last_job = $exec->add_job ( job => $job );
 
-	$last_job->set_cb_finished ( sub {
-		$self->create_splitted_vobsub (
-			exec     => $exec,
-			last_job => $last_job
-		);
-		1;
-	} );
+	$self->create_splitted_vobsub (
+		exec     => $exec,
+		last_job => $last_job
+	);
 
 	$exec->execute_jobs;
 
@@ -1795,7 +1876,7 @@ sub scan_rescale_volume {
 
 	if ( not $title->is_ripped ) {
 		$self->message_window (
-			message => "You first have to rip this title."
+			message => __"You first have to rip this title."
 		);
 		return 1;
 	}
@@ -1847,21 +1928,21 @@ sub add_to_cluster {
 
 	if ( $title->tc_use_chapter_mode ) {
 		$self->message_window (
-			message => "Titles in chapter mode are not supported"
+			message => __"Titles in chapter mode are not supported"
 		);
 		return 1;
 	}
 
 	if ( $title->tc_psu_core ) {
 		$self->message_window (
-			message => "PSU core mode currently not supported"
+			message => __"PSU core mode currently not supported"
 		);
 		return 1;
 	}
 
 	if ( $title->project->rip_mode ne 'rip' ) {
 		$self->message_window (
-			message => "Cluster mode is only supported\nfor ripped DVD's."
+			message => __"Cluster mode is only supported\nfor ripped DVD's."
 		);
 		return 1;
 	}
@@ -1869,21 +1950,21 @@ sub add_to_cluster {
 
 	if ( not $title->is_ripped ) {
 		$self->message_window (
-			message => "You first have to rip this title."
+			message => __"You first have to rip this title."
 		);
 		return 1;
 	}
 
 	if ( $title->get_first_audio_track < 0 ) {
 		$self->message_window (
-			message => "You have no target audio track selected."
+			message => __"You have no target audio track selected."
 		);
 		return 1;
 	}
 
 	if ( $title->tc_container eq 'vcd' ) {
 		$self->message_window (
-			message => "MPEG processing is not supported for cluster mode."
+			message => __"MPEG processing is not supported for cluster mode."
 		);
 		return 1;
 	}
@@ -1892,8 +1973,8 @@ sub add_to_cluster {
 	     $title->tc_end_frame ne '' ) {
 		$self->message_window (
 			message =>
-				"WARNING: your frame range setting\n".
-				"is ignored in cluster mode"
+				__"WARNING: your frame range setting\n".
+                                 "is ignored in cluster mode"
 		);
 	}
 
@@ -1984,7 +2065,7 @@ sub open_video_configure_window {
 	my $out_filename = $in_filename;
 
 	if ( not -f $in_filename ) {
-		system ("xvid4conf '$out_filename' &");
+		system ("xvid4conf '$out_filename' '$ENV{HOME}/.transcode/xvid4.cfg' &");
 	} else {
 		system ("xvid4conf '$out_filename' '$in_filename' &");
 	}
