@@ -1,4 +1,4 @@
-# $Id: GrabPreviewFrame.pm,v 1.3 2003/01/28 20:19:57 joern Exp $
+# $Id: GrabPreviewFrame.pm,v 1.5.2.2 2006/03/18 11:23:01 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::GrabPreviewFrame;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Job;
 
@@ -28,9 +29,9 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info =
-		"Grabbing preview - title #".$self->title->nr.", frame #".
-		$self->title->preview_frame_nr;
+	my $info =__"Grabbing preview";
+	$info .= " - ".__x("title #{title}", title => $self->title->nr);
+	$info .= " ,".__x("frame #{frame}", frame => $self->title->preview_frame_nr);
 
 	return $info;
 }
@@ -41,7 +42,8 @@ sub init {
 	my $title = $self->title;
 	
 	if ( $title->project->rip_mode eq 'rip' and
-	     $title->has_vob_nav_file ) {
+	     $title->has_vob_nav_file and
+	     !$title->tc_force_slow_grabbing ) {
 		$self->set_progress_show_fps ( 0 );
 		$self->set_progress_max ( 5 );
 		$self->set_progress_cnt ( 5 );
@@ -68,7 +70,7 @@ sub parse_output {
 	my ($line) = @_;
 
 	if ( $self->slow_mode ) {
-		$line =~ /\[\d{6}-(\d+)\]/;
+		$line =~ /\[\d+-(\d+)\]/;
 		$self->set_progress_cnt($1) if $1;
 	}
 	
@@ -77,7 +79,8 @@ sub parse_output {
 			$self->set_operation_successful (1);
 		} else {
 			$self->set_error_message (
-				"transcode can't find this frame."
+				__"transcode can't find this frame. ".
+				  "Try forcing slow frame grabbing."
 			);
 			$self->abort_job;
 		}
