@@ -1,4 +1,4 @@
-# $Id: TranscodeVideo.pm,v 1.12 2004/04/11 23:36:20 joern Exp $
+# $Id: TranscodeVideo.pm,v 1.13.2.2 2006/03/18 11:23:01 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -110,7 +110,7 @@ sub get_diskspace_needed {
 		with_sheet	=> 0,
 	);
 
-	$bc->calculate_video_bitrate;
+	$bc->calculate;
 
 	$title->set_actual_chapter(undef);
 
@@ -161,7 +161,7 @@ sub parse_output {
 		$self->set_psu_frames($self->progress_cnt);
 	}
 
-	if ( $line =~ /\[(\d{6}-)?(\d+)\]/ ) {
+	if ( $line =~ /\[(\d+-)?(\d+)\]/ ) {
 		$self->set_progress_start_time(time)
 			if not $self->progress_start_time;
 		$self->set_progress_cnt(
