@@ -1,4 +1,4 @@
-# $Id: Subtitle.pm,v 1.6 2004/04/11 23:36:19 joern Exp $
+# $Id: Subtitle.pm,v 1.6.2.1 2005/08/14 16:19:49 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -195,7 +195,7 @@ sub new {
 	my %par = @_;
 	my ($filename, $time) = @par{'filename','time'};
 
-	my $catch = qx[identify -ping $filename 2>&1];
+	my $catch = qx[identify $filename 2>&1];
 	my ($width, $height);
 	($width, $height) = ( $catch =~ /(\d+)x(\d+)/ );
 
