@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.154 2005/06/19 13:58:01 joern Exp $
+# $Id: Title.pm,v 1.154.2.3 2006/03/18 11:06:28 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -500,7 +500,7 @@ sub transcode_data_source {
 	my $source;
 
 	if ( $mode eq 'rip' ) {
-		$source = $self->vob_dir;
+		$source = $self->vob_dir."/";
 
 	} elsif ( $mode eq 'dvd' ) {
 		$source = $project->dvd_device;
@@ -2205,10 +2205,10 @@ sub get_merge_audio_command {
 
 		$command .=
 			"dr_exec avimerge".
-			" -i $avi_file".
 			" -p $audio_file".
 			" -a $target_nr".
-			" -o $avi_file.merged &&".
+			" -o $avi_file.merged".
+			" -i $avi_file &&".
 			" mv $avi_file.merged $avi_file &&".
 			" rm $audio_file &&".
 			" echo DVDRIP_SUCCESS";
@@ -2595,7 +2595,7 @@ sub make_preview_clip {
 	my $target_file = $self->preview_filename( type => $type );
 	
 	my $catch = $self->system (
-		command => "identify -ping $source_file"
+		command => "identify $source_file"
 	);
 	my ($width, $height);
 	($width, $height) = ( $catch =~ /(\d+)x(\d+)/ );
@@ -2653,7 +2653,7 @@ sub make_preview_zoom {
 	}
 	
 	my $catch = $self->system (
-		command => "identify -ping $source_file"
+		command => "identify $source_file"
 	);
 	my ($width, $height);
 	($width, $height) = ( $catch =~ /(\d+)x(\d+)/ );
